'use strict';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var CardSectionType;
(function (CardSectionType) {
    CardSectionType[CardSectionType["Header"] = 0] = "Header";
    CardSectionType[CardSectionType["Footer"] = 1] = "Footer";
})(CardSectionType || (CardSectionType = {}));
var ComponentSize;
(function (ComponentSize) {
    ComponentSize["Large"] = "large";
    ComponentSize["Medium"] = "medium";
    ComponentSize["Small"] = "small";
    ComponentSize["XSmall"] = "xsmall";
})(ComponentSize || (ComponentSize = {}));
var ComponentPosition;
(function (ComponentPosition) {
    ComponentPosition[ComponentPosition["Top"] = 0] = "Top";
    ComponentPosition[ComponentPosition["Bottom"] = 1] = "Bottom";
    ComponentPosition[ComponentPosition["Left"] = 2] = "Left";
    ComponentPosition[ComponentPosition["Right"] = 3] = "Right";
})(ComponentPosition || (ComponentPosition = {}));
var InputValidationType;
(function (InputValidationType) {
    InputValidationType[InputValidationType["Error"] = 0] = "Error";
    InputValidationType[InputValidationType["Valid"] = 1] = "Valid";
    InputValidationType[InputValidationType["Empty"] = 2] = "Empty";
})(InputValidationType || (InputValidationType = {}));

var revel = {
    name: 'Revel',
    fontSizes: [10, 12, 14, 16, 18, 20, 24, 30, 36, 42, 52, 60, 68, 72, 76],
    fontWeights: [400, 600, 500, 700, 800],
    lineHeights: [14, 16, 18, 20, 22, 24, 28, 32, 38, 44, 52, 68, 76, 84, 88, 92],
    mediaQueries: {
        mobile: 0,
        desktop: 1200,
    },
    radius: {
        regular: '8px',
    },
    zIndex: {
        modal: 50,
        overlay: 49,
    },
    colors: {
        pallete: {
            primary: {
                color: '#EFD6D2',
                contrast: '--colors-shades-10-color',
                soft: {
                    color: '#fcd9d1',
                    contrast: '--colors-shades-700-color',
                },
                20: {
                    color: '#FCF7F6',
                    contrast: '--colors-shades-10-color',
                    soft: {
                        color: '#fef7f6',
                        contrast: '--colors-shades-700-color',
                    },
                },
                40: {
                    color: '#F9EFED',
                    contrast: '--colors-shades-10-color',
                    soft: {
                        color: '#fef0ed',
                        contrast: '--colors-shades-700-color',
                    },
                },
                60: {
                    color: '#F5E6E4',
                    contrast: '--colors-shades-10-color',
                    soft: {
                        color: '#fde8e3',
                        contrast: '--colors-shades-700-color',
                    },
                },
                80: {
                    color: '#F2DEDB',
                    contrast: '--colors-shades-10-color',
                    soft: {
                        color: '#fde1da',
                        contrast: '--colors-shades-700-color',
                    },
                },
            },
            secondary: __assign({
                color: '#292929',
                contrast: '--colors-shades-white-color',
                soft: {
                    color: '#bbbbbb',
                    contrast: '--colors-shades-700-color',
                },
            }, { 20: {
                    color: '#d4d4d4',
                    contrast: '--colors-shades-700-color',
                    soft: {
                        color: '#f1f1f1',
                        contrast: '--colors-shades-700-color',
                    },
                }, 40: {
                    color: '#a9a9a9',
                    contrast: '--colors-shades-700-color',
                    soft: {
                        color: '#e4e4e4',
                        contrast: '--colors-shades-700-color',
                    },
                }, 60: {
                    color: '#7f7f7f',
                    contrast: '--colors-shades-white-color',
                    soft: {
                        color: '#d6d6d6',
                        contrast: '--colors-shades-700-color',
                    },
                }, 80: {
                    color: '#545454',
                    contrast: '--colors-shades-white-color',
                    soft: {
                        color: '#c9c9c9',
                        contrast: '--colors-shades-700-color',
                    },
                } }),
            wine: {
                color: '#882A2B',
                contrast: '--colors-shades-white-color',
                soft: {
                    color: '#DBBFBF',
                    contrast: '--colors-text-color',
                },
            },
            red: {
                color: '#D3373C',
                contrast: '--colors-shades-white-color',
                soft: {
                    color: '#DBBFBF',
                    contrast: '--colors-text-color',
                },
            },
            creamy: {
                color: '#FFE9D8',
                contrast: '--colors-text-color',
                soft: {
                    color: '#FFF6EF',
                    contrast: '--colors-text-color',
                },
            },
            ocean: {
                color: '#2B526D',
                contrast: '--colors-shades-white-color',
                soft: {
                    color: '#BFCBD3',
                    contrast: '--colors-shades-700-color',
                },
            },
            softpink: {
                color: '#E3B7B2',
                contrast: '--colors-shades-10-color',
            },
            earth: {
                color: '#E7B8A6',
                contrast: '--colors-shades-10-color',
            },
            salmon: {
                color: '#DA918A',
                contrast: '--colors-shades-10-color',
            },
            softocean: {
                color: '#B5D6D0',
                contrast: '--colors-shades-10-color',
            },
            darkcreamy: {
                color: '#F5DECE',
                contrast: '--colors-shades-10-color',
            },
        },
        shades: {
            black: { color: '#000', contrast: '--colors-shades-white-color' },
            white: { color: '#fff', contrast: '--colors-shades-700-color' },
            5: { color: '#fafafa', contrast: '--colors-shades-700-color' },
            10: { color: '#f7f7f7', contrast: '--colors-shades-700-color' },
            50: { color: '#efefef', contrast: '--colors-shades-700-color' },
            100: { color: '#e5e5e5', contrast: '--colors-shades-700-color' },
            150: { color: '#d1d1d1', contrast: '--colors-shades-700-color' },
            175: { color: '#c4c4c4', contrast: '--colors-shades-700-color' },
            200: { color: '#bbbbbb', contrast: '--colors-shades-700-color' },
            250: { color: '#a6a6a6', contrast: '--colors-shades-700-color' },
            300: { color: '#9e9e9e', contrast: '--colors-shades-700-color' },
            350: { color: '#949494', contrast: '--colors-shades-white-color' },
            400: { color: '#808080', contrast: '--colors-shades-white-color' },
            450: { color: '#767676', contrast: '--colors-shades-white-color' },
            500: { color: '#5a5a5a', contrast: '--colors-shades-white-color' },
            550: { color: '#3a3a3a', contrast: '--colors-shades-white-color' },
            600: { color: '#343434', contrast: '--colors-shades-white-color' },
            650: { color: '#2d2d2d', contrast: '--colors-shades-white-color' },
            700: { color: '#292929', contrast: '--colors-shades-white-color' },
            750: { color: '#232323', contrast: '--colors-shades-white-color' },
            800: { color: '#202020', contrast: '--colors-shades-white-color' },
            850: { color: '#1b1b1b', contrast: '--colors-shades-white-color' },
            900: { color: '#191919', contrast: '--colors-shades-white-color' },
            950: { color: '#141414', contrast: '--colors-shades-white-color' },
            990: { color: '#0b0b0b', contrast: '--colors-shades-white-color' },
        },
        semantic: {
            positive: { color: '#2F806A', contrast: '--colors-shades-white-color' },
            urgent: { color: '#C64844', contrast: '--colors-shades-white-color' },
            attention: { color: '#F2D96F', contrast: '--colors-shades-700-color' },
            informative: { color: '#0A609B', contrast: '--colors-shades-700-color' },
        },
        border: {
            color: '',
            disabled: '--colors-shades-200-color',
            highlight: '--colors-shades-700-color',
        },
        background: {
            color: '--colors-shades-white-color',
            disabled: '--colors-shades-50-color',
        },
        text: {
            color: '--colors-shades-700-color',
            disabled: '--colors-shades-250-color',
        },
    },
    component: {
        button: {
            border: 'none',
            borderRadius: '2.5rem',
            fontWeight: 700,
            lineHeight: '20px',
            letterSpacing: '0.2em',
            minWidth: '300px',
            minHeight: '48px',
            size: {
                small: {
                    fontSize: '0.75rem',
                    padding: '0.25rem 1rem',
                },
                medium: {
                    fontSize: '0.875rem',
                    padding: '0.5rem 1.5rem',
                },
                large: {
                    fontSize: '1rem',
                    padding: '0.75rem 2rem',
                },
            },
            primary: {
                active: {
                    backgroundColor: '#DA918A',
                    color: '--colors-pallete-primary-contrast',
                },
                hover: {
                    backgroundColor: '--colors-pallete-primary-soft-color',
                    color: '--colors-pallete-primary-soft-contrast',
                },
            },
            secondary: {
                active: {
                    backgroundColor: '--colors-pallete-secondary-color',
                    color: '--colors-pallete-secondary-contrast',
                },
                hover: {
                    backgroundColor: '--colors-pallete-secondary-80-color',
                    color: '--colors-pallete-secondary-contrast',
                },
            },
        },
        input: {
            background: '--colors-shades-white-color',
            color: '--colors-shades-700-color',
            placeholderColor: '--colors-shades-250-color',
            borderRadius: '2.5rem',
            fontSize: '1rem',
            fontWeight: 400,
            padding: '0.75rem 1rem',
            lineHeight: '1.5rem',
            border: '0.063rem solid var(--colors-shades-200-color)',
            boxShadow: 'none',
            errorBorder: '0.09375rem solid #d3373c',
        },
        inputPlaceholder: {
            fontSize: '0.875rem',
            padding: '1.125rem 0.9375rem 0.3rem 0.9375rem',
            focusBorder: '0.09375rem solid #1990c6',
        },
        inputCustom: {
            button: {
                borderRadius: '0 0.5rem 0.5rem 0',
            },
            input: {
                borderRadius: '0.5rem 1rem 1rem 0.5rem',
            },
        },
        selector: {
            size: {
                small: {
                    padding: '0.625rem 1.25rem',
                    borderRadius: '0.5rem',
                },
                medium: {
                    padding: '0.25rem 1rem',
                    borderRadius: '0.375rem',
                },
            },
            default: {
                fontWeight: 600,
                border: '0.063rem solid var(--colors-shades-250-color)',
                background: '--colors-shades-white-color',
                color: '--colors-shades-700-color',
            },
            hover: {
                fontWeight: 600,
                background: '--colors-shades-700-color',
                border: 'none',
                color: '--colors-shades-white-color',
            },
            noStock: {
                fontWeight: 600,
                background: 'transparent',
                border: '1px solid #3a3a3a4d',
                color: '#3a3a3a4d',
            },
            disabled: {
                border: 'none',
            },
            fontSize: '0.75rem',
        },
        rating: {
            fontWeight: 400,
            size: {
                xsmall: {
                    fontSize: '0.625rem',
                    lineHeight: '0.625rem',
                },
                small: {
                    fontSize: '0.875rem',
                    lineHeight: '0.875rem',
                },
                medium: {
                    fontSize: '1rem',
                    lineHeight: '1rem',
                },
                large: {
                    fontSize: '1.125rem',
                    lineHeight: '1.125rem',
                },
            },
        },
        stars: {
            element: {
                color: '#E7B8A6',
                xsmall: {
                    width: '0.656rem',
                    height: '0.656rem',
                    marginRight: '0.156rem',
                },
                small: {
                    width: '0.875rem',
                    height: '0.875rem',
                    marginRight: '0.25rem',
                },
                medium: {
                    width: '1.375rem',
                    height: '1.375rem',
                    marginRight: '0.375rem',
                },
                large: {
                    width: '2.375rem',
                    height: '2.375rem',
                    marginRight: '0.375rem',
                },
            },
        },
        card: {
            borderRadius: '1.25rem',
            backgroundColor: '#F5DECE',
        },
        radio: {
            borderColor: '--colors-shades-700-color',
            background: '--colors-shades-white-color',
            textSize: '14px',
            lineHeight: '22px',
            size: {
                large: {
                    borderWidth: '0.094rem',
                    margin: '0.5rem',
                    height: '2.25rem',
                    active: {
                        borderWidth: '0.875rem',
                    },
                },
                medium: {
                    borderWidth: '0.094rem',
                    margin: '0.375rem',
                    height: '1.375rem',
                    active: {
                        borderWidth: '0.5rem',
                    },
                },
                small: {
                    borderWidth: '0.063rem',
                    margin: '0.375rem',
                    height: '0.875rem',
                    active: {
                        borderWidth: '0.313rem',
                    },
                },
            },
        },
        label: {
            color: '--colors-shades-400-color',
            fontSize: {
                small: '0.75rem',
                medium: '0.75rem',
                large: '0.875rem',
            },
            lineHeight: {
                small: '1rem',
                medium: '1rem',
                large: '1.125rem',
            },
        },
        checkbox: {
            background: '--colors-shades-white-color',
            borderColor: '--colors-shades-700-color',
            active: {
                background: '--colors-shades-700-color',
            },
            size: {
                large: {
                    width: '1.8rem',
                    height: '1.8rem',
                    borderRadius: '0.25rem',
                    borderWidth: '0.094rem',
                    margin: '0.6rem',
                    icon: {
                        width: '1.1rem',
                        height: '0.8rem',
                    },
                },
                medium: {
                    width: '1.375rem',
                    height: '1.375rem',
                    borderRadius: '0.25rem',
                    borderWidth: '0.094rem',
                    margin: '0.438rem',
                    icon: {
                        width: '0.875rem',
                        height: '0.625rem',
                    },
                },
                small: {
                    width: '0.875rem',
                    height: '0.875rem',
                    borderRadius: '0.125rem',
                    borderWidth: '0.063rem',
                    margin: '0.563rem',
                    icon: {
                        width: '0.5rem',
                        height: '0.375rem',
                    },
                },
            },
        },
        accordion: {
            variant: {
                box: {
                    container: {
                        border: '0.063rem solid',
                        borderColor: '--colors-shades-100-color',
                        borderRadius: '0.25rem',
                        padding: '1.25rem 2rem',
                    },
                    summary: {
                        fontWeight: 600,
                        fontSize: '20px',
                        lineHeight: '28px',
                        color: '--colors-shades-700-color',
                    },
                    details: {
                        margin: '10px 0px 0px 0px',
                    },
                    icon: {
                        width: 1.5,
                        height: 1.5,
                        color: '--colors-shades-700-color',
                    },
                },
                simple: {
                    container: {
                        borderTop: '1px solid',
                        borderColor: '--colors-shades-100-color',
                        borderBottom: 'none',
                        borderRadius: 'none',
                        padding: '10px 0px',
                    },
                    summary: {
                        fontWeight: 400,
                        fontSize: '20px',
                        lineHeight: '28px',
                        color: '--colors-shades-700-color',
                    },
                    details: {
                        margin: '10px 0px 0px 0px',
                    },
                    icon: {
                        width: 1,
                        height: 1,
                        color: '--colors-shades-700-color',
                    },
                },
            },
        },
        dropdown: {
            borderRadius: '2.5rem',
            fontSize: '0.875rem',
            fontWeight: 600,
            lineHeight: '1.125rem',
            padding: '0.5rem 0.75rem 0.5rem 1rem',
            optionPadding: '0.75rem 1rem 0.625rem 0.75rem',
            color: '--colors-shades-700-color',
            fill: '--colors-shades-700-color',
            options: {
                borderColor: '--colors-shades-700-color',
                color: '--colors-shades-700-color',
                borderRadius: '0.5rem',
                borderRadiusV2: '0.5rem',
            },
            optionsWrapper: {
                borderRadius: 'unset',
                overflow: 'unset',
            },
        },
        modal: {
            minWidth: '540px',
        },
        packSelector: {
            borderRadius: '8px',
            borderColor: '--colors-shades-100-color',
            highlightColor: '--colors-pallete-creamy-soft-color',
            selectedColor: '--colors-semantic-positive-color',
            selectedContrast: '--colors-semantic-positive-contrast',
            tagColor: '--colors-semantic-attention-color',
        },
        slideNavigation: {
            slideDots: {
                unselectedDotColor: 'transparent',
                selectedDotColor: '--colors-shades-700-color',
                dotsOpacity: 0.9,
            },
        },
        beforeAfter: {
            size: {
                small: {
                    image: {
                        minHeight: 'auto',
                        minWidth: '92px',
                        mobile: {
                            minHeight: '138px',
                            minWidth: '128px',
                        },
                    },
                    imageContainer: {
                        maxWidth: '214px',
                        padding: '12px',
                        mobile: {
                            maxWidth: '286px',
                        },
                    },
                    userInfoText: {
                        fontSize: '12px',
                        mobile: {
                            fontSize: '12px',
                        },
                    },
                },
                medium: {
                    image: {
                        minHeight: '200px',
                        minWidth: '187px',
                        mobile: {
                            minHeight: '157px',
                            minWidth: '150px',
                        },
                    },
                    imageContainer: {
                        maxWidth: '427px',
                        padding: '18px',
                        mobile: {
                            maxWidth: '342px',
                        },
                    },
                    userInfoText: {
                        fontSize: '18px',
                        mobile: {
                            fontSize: '14px',
                        },
                    },
                },
                large: {
                    image: {
                        minHeight: '200px',
                        minWidth: '187px',
                        mobile: {
                            minHeight: '157px',
                            minWidth: '150px',
                        },
                    },
                    imageContainer: {
                        maxWidth: '427px',
                        padding: '18px',
                        mobile: {
                            maxWidth: '342px',
                        },
                    },
                    userInfoText: {
                        fontSize: '18px',
                        mobile: {
                            fontSize: '14px',
                        },
                    },
                },
            },
        },
        total: {
            basicTotal: {
                amount: {
                    color: '--colors-pallete-secondary-color',
                    fontSize: '24px',
                },
                currency: {
                    color: '#A6A6A6',
                    fontSize: '16px',
                    lineHeight: '24px',
                    alignSelf: 'flex-end',
                },
                savings: {
                    amountFontWeight: 700,
                    color: '--colors-semantic-positive-color',
                },
            },
        },
        subTotal: {
            basicSubTotal: {
                family: 'Jost',
                size: '14px',
                weight: 700,
                lineHeight: '20px',
                color: '--colors-pallete-secondary-color',
            },
        },
        pricing: {
            priceLabel: {
                price: {
                    size: ComponentSize.Medium,
                    originalPriceColor: '--colors-shades-400-color',
                    actualPriceColor: '--colors-semantic-urgent-color',
                },
            },
        },
        orderSummary: {
            headingTextAlign: 'center',
            backgroundColor: '--colors-shades-10-color',
            padding: '20px',
            borderRadius: '--radius-regular',
            maxWidth: '100%',
            onMobile: {
                maxWidth: '100%',
                padding: '15px',
            },
        },
        expressCheckout: {
            button: {
                borderRadius: '4px',
            },
        },
        copyrightText: {
            fontSize: '14px',
            fontWeight: 400,
            lineHeight: '22px',
            color: '--colors-shades-400-color',
        },
        thankyouFooterText: {
            fontSize: '14px',
            fontWeight: '700',
            lineHeight: '20px',
        },
        textButton: {
            fontWeight: 600,
            lineHeight: '22px',
        },
        deliveryDetails: {
            title: {
                fontSize: '1.25rem',
                lineHeight: '1.75rem',
                fontWeight: 600,
            },
            sectionTitle: {
                fontSize: '1rem',
                lineHeight: '1.25rem',
                fontWeight: 600,
            },
            note: {
                accentColor: '--colors-semantic-urgent-color',
                color: '--colors-text-color',
                backgroundColor: '#F5DECE',
            },
            sectionDetails: {
                marginLeft: '1.813rem',
                fontSize: '1rem',
                lineHeight: '1.25rem',
                fontWeight: 400,
            },
        },
        text: {
            orderHeader: {
                color: '--colors-shades-650-color',
            },
            fitGuarantee: {
                fontWeight: 'unset',
            },
            offerBanner: {
                borderRadius: '0.125rem',
            },
        },
        orderBar: {
            backgroundColor: '#FAF7F2',
            fontColor: '--colors-shades-700-color',
        },
        banner: {
            outlineColor: '--colors-semantic-positive-color',
            filledColor: '--colors-semantic-positive-color',
            fontColor: '--colors-shades-white-color',
        },
        offerTitleText: {
            size: '18px',
            weight: 700,
            lineHeight: '1.7rem',
        },
        linePrice: {
            color: '--colors-semantic-urgent-color',
            badge: {
                color: '--colors-semantic-urgent-color',
                borderRadius: '8px',
            },
        },
        divider: {
            color: '--colors-pallete-secondary-soft-color',
        },
        checkout: {
            paymentInformation: {
                borderRadius: '8px',
            },
            creditCardSection: {
                borderRadius: '8px',
            },
        },
        upsell: {
            banner: {
                outlined: {
                    color: '--colors-semantic-positive-color',
                },
            },
            price: {
                colors: {
                    regular: '--colors-shades-400-color',
                    deal: '#DA918A',
                    each: '--colors-shades-700-color',
                    badgeBG: '#DA918A',
                    badgeColor: '--colors-shades-white-color',
                },
            },
            hurryTimeCard: {
                backgroundColor: '#EFD6D2',
            },
        },
        thankyou: {
            emailSection: {
                backgroundColor: '#F5DECE',
            },
            socialIcon: {
                color: '#DA918A',
            },
            orderId: {
                color: '--colors-shades-700-color',
            },
        },
        hurryUp: {
            borderRadius: 'unset',
        },
        qtyPicker: {
            borderRadius: '0.5rem',
        },
    },
    typography: {
        config: {
            weight: {
                heavy: 900,
                bold: 700,
                demi: 600,
                regular: 400,
            },
        },
        variants: {
            hero1: {
                fontSize: 76,
                lineHeight: '92px',
            },
            hero2: {
                fontSize: 72,
                lineHeight: '88px',
            },
            hero3: {
                fontSize: 68,
                lineHeight: '84px',
            },
            display1: {
                fontSize: 60,
                lineHeight: '76px',
            },
            display2: {
                fontSize: 52,
                lineHeight: '68px',
            },
            heading1: {
                fontSize: 42,
                lineHeight: '52px',
            },
            heading2: {
                fontSize: 36,
                lineHeight: '44px',
            },
            heading3: {
                fontSize: 30,
                lineHeight: '38px',
            },
            heading4: {
                fontSize: 24,
                lineHeight: '32px',
            },
            heading5: {
                fontSize: 20,
                lineHeight: '28px',
            },
            heading6: {
                fontSize: 18,
                lineHeight: '22px',
            },
            heading7: {
                fontSize: 20,
                lineHeight: '28px',
            },
            heading8: {
                fontSize: 18,
                lineHeight: '28px',
            },
            'body-regular': {
                fontSize: 16,
                lineHeight: '24px',
            },
            'body-small': {
                fontSize: 14,
                lineHeight: '22px',
            },
            'link-regular': {
                fontSize: 16,
                lineHeight: '24px',
            },
            'link-small': {
                fontSize: 14,
                lineHeight: '22px',
            },
            'pricing-large': {
                fontSize: 24,
                lineHeight: '32px',
            },
            'pricing-medium': {
                fontSize: 18,
                lineHeight: '24px',
            },
            'pricing-regular': {
                fontSize: 16,
                lineHeight: '32px',
            },
            'pricing-small': {
                fontSize: 14,
                lineHeight: '20px',
            },
            button: {
                textTransform: 'uppercase',
            },
            'button-large': {
                fontSize: 16,
                lineHeight: '20px',
            },
            'button-regular': {
                fontSize: 14,
                lineHeight: '18px',
            },
            'button-small': {
                fontSize: 12,
                lineHeight: '16px',
            },
            'label-regular': {
                fontSize: 14,
                lineHeight: '18px',
            },
            'label-small': {
                fontSize: 12,
                lineHeight: '16px',
            },
            'tag-regular': {
                fontSize: 12,
                lineHeight: '16px',
            },
            'tag-small': {
                fontSize: 10,
                lineHeight: '14px',
            },
            'tag-x-small': {
                fontSize: 8,
                lineHeight: '12px',
            },
        },
    },
    fonts: {
        url: 'https://cdn.jsdelivr.net/gh/trafilea/storefront-static@main/fonts/revel',
        config: [
            {
                family: 'Jost',
                src: 'Jost400Book.otf',
                weight: 400,
            },
            {
                family: 'Jost',
                src: 'Jost100Hairline.otf',
                weight: 100,
            },
            {
                family: 'Jost',
                src: 'Jost200Thin.otf',
                weight: 200,
            },
            {
                family: 'Jost',
                src: 'Jost300Light.otf',
                weight: 300,
            },
            {
                family: 'Jost',
                src: 'Jost500Medium.otf',
                weight: 500,
            },
            {
                family: 'Jost',
                src: 'Jost600Semi.otf',
                weight: 600,
            },
            {
                family: 'Jost',
                src: 'Jost700Bold.otf',
                weight: 700,
            },
            {
                family: 'Jost',
                src: 'Jost800Heavy.otf',
                weight: 800,
                stretch: 'condensed',
            },
            {
                family: 'Jost',
                src: 'Jost900Black.otf',
                weight: 900,
                stretch: 'condensed',
            },
            {
                family: 'Jost',
                src: 'Jost100HairlineItalic.otf',
                weight: 100,
                style: 'italic',
            },
            {
                family: 'Jost',
                src: 'Jost200ThinItalic.otf',
                weight: 200,
                style: 'italic',
            },
            {
                family: 'Jost',
                src: 'Jost300LightItalic.otf',
                weight: 300,
                style: 'italic',
            },
            {
                family: 'Jost',
                src: 'Jost400BookItalic.otf',
                weight: 400,
                style: 'italic',
            },
            {
                family: 'Jost',
                src: 'Jost500MediumItalic.otf',
                weight: 500,
                style: 'italic',
            },
            {
                family: 'Jost',
                src: 'Jost600SemiItalic.otf',
                weight: 600,
                style: 'italic',
            },
            {
                family: 'Jost',
                src: 'Jost700BoldItalic.otf',
                weight: 700,
                style: 'italic',
            },
            {
                family: 'Jost',
                src: 'Jost800HeavyItalic.otf',
                weight: 800,
                style: 'italic',
            },
            {
                family: 'Jost',
                src: 'Jost900BlackItalic.otf',
                weight: 900,
                style: 'italic',
            },
            {
                family: 'Georgia',
                src: 'Georgia-Regular.otf',
                weight: 400,
            },
            {
                family: 'Georgia',
                src: 'Georgia-Bold.otf',
                weight: 700,
            },
        ],
    },
    assets: {
        cdn: 'https://cdn.jsdelivr.net/gh/trafilea/storefront-static@1.3.4/common',
        images: {
            favicon: 'https://cdn11.bigcommerce.com/s-fjtlubkm6t/images/stencil/original/image-manager/favicon.png',
            logo: 'https://cdn.jsdelivr.net/gh/trafilea/storefront-static@main/images/revel/revelbeauty.svg',
            logoSize: {
                width: '342',
                height: '22',
            },
            logoMobile: 'https://cdn.jsdelivr.net/gh/trafilea/storefront-static@main/images/revel/revelbeauty_logo_mobile.svg',
            upsellLogo: {
                url: 'https://cdn.jsdelivr.net/gh/trafilea/storefront-static@main/images/revel/revelbeauty.svg',
                width: '210',
                height: '60',
            },
            tyLogo: {
                url: 'https://cdn.jsdelivr.net/gh/trafilea/storefront-static@main/images/revel/revelbeauty.svg',
                width: '410',
                height: '28',
            },
        },
    },
};

module.exports = revel;
