'use strict';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var CardSectionType;
(function (CardSectionType) {
    CardSectionType[CardSectionType["Header"] = 0] = "Header";
    CardSectionType[CardSectionType["Footer"] = 1] = "Footer";
})(CardSectionType || (CardSectionType = {}));
var ComponentSize;
(function (ComponentSize) {
    ComponentSize["Large"] = "large";
    ComponentSize["Medium"] = "medium";
    ComponentSize["Small"] = "small";
    ComponentSize["XSmall"] = "xsmall";
})(ComponentSize || (ComponentSize = {}));
var ComponentPosition;
(function (ComponentPosition) {
    ComponentPosition[ComponentPosition["Top"] = 0] = "Top";
    ComponentPosition[ComponentPosition["Bottom"] = 1] = "Bottom";
    ComponentPosition[ComponentPosition["Left"] = 2] = "Left";
    ComponentPosition[ComponentPosition["Right"] = 3] = "Right";
})(ComponentPosition || (ComponentPosition = {}));
var InputValidationType;
(function (InputValidationType) {
    InputValidationType[InputValidationType["Error"] = 0] = "Error";
    InputValidationType[InputValidationType["Valid"] = 1] = "Valid";
    InputValidationType[InputValidationType["Empty"] = 2] = "Empty";
})(InputValidationType || (InputValidationType = {}));

var truekind = {
    name: 'Truekind',
    fontSizes: [10, 12, 14, 16, 18, 20, 24, 30, 36, 42, 52, 60, 68, 72, 76],
    fontWeights: [400, 600, 500, 700, 800],
    lineHeights: [14, 16, 18, 20, 22, 24, 28, 32, 38, 44, 52, 68, 76, 84, 88, 92],
    mediaQueries: {
        mobile: 0,
        desktop: 1200,
    },
    radius: {
        regular: '8px',
    },
    zIndex: {
        modal: 50,
        overlay: 49,
    },
    colors: {
        pallete: {
            primary: __assign({
                color: '#cc4125',
                contrast: '--colors-shades-white-color',
                soft: { color: '', contrast: '' },
            }, { 20: {
                    color: '#f5d9d3',
                    contrast: '--colors-shades-700-color',
                    soft: { color: '', contrast: '' },
                }, 40: {
                    color: '#ebb3a8',
                    contrast: '--colors-shades-700-color',
                    soft: { color: '', contrast: '' },
                }, 60: {
                    color: '#e08d7c',
                    contrast: '--colors-shades-700-color',
                    soft: { color: '', contrast: '' },
                }, 80: {
                    color: '#d66751',
                    contrast: '--colors-shades-700-color',
                    soft: { color: '', contrast: '' },
                } }),
            secondary: __assign({
                color: '#292929',
                contrast: '--colors-shades-white-color',
                soft: { color: '#bbbbbb', contrast: '--colors-shades-700-color' },
            }, { 20: {
                    color: '#d4d4d4',
                    contrast: '--colors-shades-700-color',
                    soft: { color: '#f1f1f1', contrast: '--colors-shades-700-color' },
                }, 40: {
                    color: '#a9a9a9',
                    contrast: '--colors-shades-700-color',
                    soft: { color: '#e4e4e4', contrast: '--colors-shades-700-color' },
                }, 60: {
                    color: '#7f7f7f',
                    contrast: '--colors-shades-white-color',
                    soft: { color: '#d6d6d6', contrast: '--colors-shades-700-color' },
                }, 80: {
                    color: '#545454',
                    contrast: '--colors-shades-white-color',
                    soft: { color: '#c9c9c9', contrast: '--colors-shades-700-color' },
                } }),
            champagne: {
                color: '#FFF5E9',
                contrast: '--colors-text-color',
                soft: {
                    color: '#FFF5E9',
                    contrast: '--colors-text-color',
                },
            },
            red: {
                color: '#D3373C',
                contrast: '--colors-shades-white-color',
                soft: {
                    color: '#DBBFBF',
                    contrast: '--colors-text-color',
                },
            },
        },
        shades: {
            black: { color: '#000', contrast: '--colors-shades-white-color' },
            white: { color: '#fff', contrast: '--colors-shades-700-color' },
            5: { color: '#fafafa', contrast: '--colors-shades-700-color' },
            10: { color: '#f7f7f7', contrast: '--colors-shades-700-color' },
            50: { color: '#efefef', contrast: '--colors-shades-700-color' },
            100: { color: '#e5e5e5', contrast: '--colors-shades-700-color' },
            150: { color: '#d1d1d1', contrast: '--colors-shades-700-color' },
            175: { color: '#c4c4c4', contrast: '--colors-shades-700-color' },
            200: { color: '#bbbbbb', contrast: '--colors-shades-700-color' },
            250: { color: '#a6a6a6', contrast: '--colors-shades-700-color' },
            300: { color: '#9e9e9e', contrast: '--colors-shades-700-color' },
            350: { color: '#949494', contrast: '--colors-shades-700-color' },
            400: { color: '#808080', contrast: '--colors-shades-700-color' },
            450: { color: '#767676', contrast: '--colors-shades-700-color' },
            500: { color: '#5a5a5a', contrast: '--colors-shades-white-color' },
            550: { color: '#3a3a3a', contrast: '--colors-shades-white-color' },
            600: { color: '#343434', contrast: '--colors-shades-white-color' },
            650: { color: '#2d2d2d', contrast: '--colors-shades-white-color' },
            700: { color: '#292929', contrast: '--colors-shades-white-color' },
            750: { color: '#232323', contrast: '--colors-shades-white-color' },
            800: { color: '#202020', contrast: '--colors-shades-white-color' },
            850: { color: '#1b1b1b', contrast: '--colors-shades-white-color' },
            900: { color: '#191919', contrast: '--colors-shades-white-color' },
            950: { color: '#141414', contrast: '--colors-shades-white-color' },
            990: { color: '#0b0b0b', contrast: '--colors-shades-white-color' },
        },
        semantic: {
            positive: { color: '#2f806a', contrast: '--colors-shades-white-color' },
            urgent: { color: '#c64844', contrast: '--colors-shades-white-color' },
            attention: { color: '#f2d96f', contrast: '--colors-shades-700-color' },
            informative: { color: '#0a609b', contrast: '--colors-shades-700-color' },
        },
        border: {
            color: '',
            disabled: '--colors-shades-200-color',
            highlight: '--colors-shades-700-color',
        },
        background: {
            color: '--colors-shades-white-color',
            disabled: '--colors-shades-50-color',
        },
        text: {
            color: '--colors-shades-700-color',
            disabled: '--colors-shades-250-color',
        },
    },
    typography: {
        config: {
            weight: {
                heavy: 900,
                bold: 700,
                demi: 600,
                regular: 400,
            },
        },
        variants: {
            hero1: {
                fontSize: 76,
                lineHeight: '92px',
            },
            hero2: {
                fontSize: 72,
                lineHeight: '88px',
            },
            hero3: {
                fontSize: 68,
                lineHeight: '84px',
            },
            display1: {
                fontSize: 60,
                lineHeight: '76px',
            },
            display2: {
                fontSize: 50,
                lineHeight: '64px',
            },
            heading1: {
                fontSize: 42,
                lineHeight: '52px',
            },
            heading2: {
                fontSize: 36,
                lineHeight: '44px',
            },
            heading3: {
                fontSize: 30,
                lineHeight: '38px',
            },
            heading4: {
                fontSize: 24,
                lineHeight: '32px',
            },
            heading5: {
                fontSize: 20,
                lineHeight: '28px',
            },
            heading6: {
                fontSize: 18,
                lineHeight: '28px',
            },
            heading7: {
                fontSize: 20,
                lineHeight: '28px',
            },
            heading8: {
                fontSize: 18,
                lineHeight: '28px',
            },
            'body-regular': {
                fontSize: 16,
                lineHeight: '24px',
            },
            'body-small': {
                fontSize: 14,
                lineHeight: '22px',
            },
            'link-regular': {
                fontSize: 16,
                lineHeight: '24px',
            },
            'link-small': {
                fontSize: 14,
                lineHeight: '22px',
            },
            'pricing-large': {
                fontSize: 24,
                lineHeight: '32px',
            },
            'pricing-medium': {
                fontSize: 18,
                lineHeight: '24px',
            },
            'pricing-regular': {
                fontSize: 16,
                lineHeight: '32px',
            },
            'pricing-small': {
                fontSize: 14,
                lineHeight: '20px',
            },
            button: {
                textTransform: 'uppercase',
            },
            'button-large': {
                fontSize: 16,
                lineHeight: '20px',
            },
            'button-regular': {
                fontSize: 14,
                lineHeight: '18px',
            },
            'button-small': {
                fontSize: 12,
                lineHeight: '16px',
            },
            'label-regular': {
                fontSize: 14,
                lineHeight: '18px',
            },
            'label-small': {
                fontSize: 12,
                lineHeight: '16px',
            },
            'tag-regular': {
                fontSize: 12,
                lineHeight: '16px',
            },
            'tag-small': {
                fontSize: 10,
                lineHeight: '14px',
            },
            'tag-x-small': {
                fontSize: 8,
                lineHeight: '12px',
            },
        },
    },
    component: {
        button: {
            border: 'none',
            borderRadius: '1.5rem',
            fontWeight: 700,
            lineHeight: 'normal',
            letterSpacing: 'normal',
            minWidth: 'unset',
            minHeight: 'unset',
            size: {
                small: {
                    fontSize: '0.75rem',
                    padding: '0.25rem 2rem',
                },
                medium: {
                    fontSize: '0.875rem',
                    padding: '0.688rem 2rem',
                },
                large: {
                    fontSize: '1rem',
                    padding: '0.75rem 3rem',
                },
            },
            primary: {
                active: {
                    backgroundColor: '#CC4125',
                    color: '#FFFFFF',
                },
                hover: {
                    backgroundColor: '#910F23',
                    color: '#FFFFFF',
                },
            },
            secondary: {
                active: {
                    backgroundColor: '#292929',
                    color: '#FFFFFF',
                },
                hover: {
                    backgroundColor: '#686872',
                    color: '#FFFFFF',
                },
            },
        },
        input: {
            background: '#FFFFFF',
            color: '#292929',
            placeholderColor: '#A6A6A6',
            borderRadius: '1.5rem',
            fontSize: '1rem',
            fontWeight: 400,
            padding: '0.75rem 1.5rem',
            lineHeight: '1.5rem',
            border: '0.063rem solid #BBBBBB',
            boxShadow: '0 0 0 0.25rem #D9EEFF',
            errorBorder: '0.09375rem solid #d3373c',
        },
        inputPlaceholder: {
            fontSize: '0.875rem',
            padding: '1.125rem 0.9375rem 0 0.9375rem',
            focusBorder: '0.09375rem solid #1990c6',
        },
        inputCustom: {
            button: {
                borderRadius: '1.5rem',
            },
            input: {
                borderRadius: '1.5rem',
            },
        },
        selector: {
            size: {
                small: {
                    padding: '0.5rem 1.5rem',
                    borderRadius: '0.375rem',
                },
                medium: {
                    padding: '0.5rem 1.5',
                    borderRadius: '0.375rem',
                },
            },
            default: {
                fontWeight: 700,
                border: '0.063rem solid #BBBBBB',
                background: '#FFFFFF',
                color: '#000000',
            },
            hover: {
                fontWeight: 700,
                background: '#292929',
                border: 'none',
                color: '#FFFFFF',
            },
            noStock: {
                fontWeight: 600,
                background: 'transparent',
                border: '1px solid #3a3a3a4d',
                color: '#3a3a3a4d',
            },
            disabled: {
                border: '0.063rem solid #E5E5E5',
            },
            fontSize: '0.875rem',
        },
        rating: {
            fontWeight: 700,
            size: {
                xsmall: {
                    fontSize: '0.625rem',
                    lineHeight: '0.625rem',
                },
                small: {
                    fontSize: '0.875rem',
                    lineHeight: '0.875rem',
                },
                medium: {
                    fontSize: '1rem',
                    lineHeight: '1rem',
                },
                large: {
                    fontSize: '1.125rem',
                    lineHeight: '1.125rem',
                },
            },
        },
        stars: {
            element: {
                color: '#F2D96F',
                xsmall: {
                    width: '0.656rem',
                    height: '0.656rem',
                    marginRight: '0.156rem',
                },
                small: {
                    width: '0.875rem',
                    height: '0.875rem',
                    marginRight: '0.25rem',
                },
                medium: {
                    width: '1.375rem',
                    height: '1.375rem',
                    marginRight: '0.375rem',
                },
                large: {
                    width: '2.375rem',
                    height: '2.375rem',
                    marginRight: '0.375rem',
                },
            },
        },
        card: {
            borderRadius: '1.5rem',
            backgroundColor: '#f7ece4',
        },
        radio: {
            borderColor: '#686872',
            background: '#FFFFFF',
            textSize: '16px',
            lineHeight: 'normal',
            size: {
                large: {
                    borderWidth: '0.094rem',
                    margin: '0.375rem',
                    height: '1.375rem',
                    active: {
                        borderWidth: '0.5rem',
                    },
                },
                medium: {
                    borderWidth: '0.094rem',
                    margin: '0.375rem',
                    height: '1.375rem',
                    active: {
                        borderWidth: '0.5rem',
                    },
                },
                small: {
                    borderWidth: '0.094rem',
                    margin: '0.375rem',
                    height: '1.375rem',
                    active: {
                        borderWidth: '0.5rem',
                    },
                },
            },
        },
        label: {
            color: '--colors-pallete-secondary-color',
            fontSize: {
                small: '0.625rem',
                medium: '0.75rem',
                large: '0.875rem',
            },
            lineHeight: {
                small: '0.875rem',
                medium: '1rem',
                large: '1.25rem',
            },
        },
        checkbox: {
            background: '#FFFFFF',
            borderColor: '#686872',
            active: {
                background: '#686872',
            },
            size: {
                large: {
                    width: '1.5rem',
                    height: '1.5rem',
                    borderRadius: '0.25rem',
                    borderWidth: '0.094rem',
                    margin: '0.375rem',
                    icon: {
                        width: '0.875rem',
                        height: '0.625rem',
                    },
                },
                medium: {
                    width: '1.5rem',
                    height: '1.5rem',
                    borderRadius: '0.25rem',
                    borderWidth: '0.094rem',
                    margin: '0.375rem',
                    icon: {
                        width: '0.875rem',
                        height: '0.625rem',
                    },
                },
                small: {
                    width: '0.875rem',
                    height: '0.875rem',
                    borderRadius: '0.25rem',
                    borderWidth: '0.094rem',
                    margin: '0.375rem',
                    icon: {
                        width: '0.5rem',
                        height: '0.375rem',
                    },
                },
            },
        },
        accordion: {
            variant: {
                box: {
                    container: {
                        border: '1px solid',
                        borderColor: '#BBBBBB',
                        borderRadius: '20px',
                        padding: '20px 32px',
                    },
                    summary: {
                        fontWeight: 400,
                        fontSize: '20px',
                        lineHeight: '28px',
                        color: '#292929',
                    },
                    details: {
                        margin: '10px 0px 0px 0px',
                    },
                    icon: {
                        width: 1.5,
                        height: 1.5,
                        color: '#292929',
                    },
                },
                simple: {
                    container: {
                        borderTop: 'none',
                        borderBottom: '1px solid',
                        borderColor: '#E5E5E5',
                        borderRadius: 'none',
                        padding: '2px 0px 12px',
                    },
                    summary: {
                        fontWeight: 700,
                        fontSize: '16px',
                        lineHeight: '24px',
                        color: '#292929',
                    },
                    details: {
                        margin: '14px 0px 0px 0px',
                    },
                    icon: {
                        width: 1,
                        height: 1,
                        color: '#292929',
                    },
                },
            },
        },
        dropdown: {
            borderRadius: '1.5rem',
            fontSize: '1rem',
            fontWeight: 600,
            lineHeight: '1.125rem',
            padding: '0.5rem 0.75rem 0.5rem 1rem',
            optionPadding: '0.75rem 1rem 0.625rem 0.75rem',
            color: '#292929',
            fill: '#292929',
            options: {
                borderColor: '#8BBEEA',
                color: '#292929',
                borderRadius: '1.25rem',
                borderRadiusV2: 'unset',
            },
            optionsWrapper: {
                borderRadius: '1.25rem',
                overflow: 'hidden',
            },
        },
        modal: {
            minWidth: '540px',
        },
        packSelector: {
            borderRadius: '8px',
            borderColor: '--colors-shades-100-color',
            highlightColor: '--colors-pallete-creamy-soft-color',
            selectedColor: '--colors-semantic-positive-color',
            selectedContrast: '--colors-semantic-positive-contrast',
            tagColor: '--colors-semantic-attention-color',
        },
        slideNavigation: {
            slideDots: {
                unselectedDotColor: '--colors-shades-700-color:',
                selectedDotColor: '--colors-shades-white-color',
                dotsOpacity: 0.6,
            },
        },
        beforeAfter: {
            size: {
                small: {
                    image: {
                        minHeight: 'auto',
                        minWidth: '92px',
                        mobile: {
                            minHeight: '138px',
                            minWidth: '128px',
                        },
                    },
                    imageContainer: {
                        maxWidth: '214px',
                        padding: '12px',
                        mobile: {
                            maxWidth: '286px',
                        },
                    },
                    userInfoText: {
                        fontSize: '12px',
                        mobile: {
                            fontSize: '12px',
                        },
                    },
                },
                medium: {
                    image: {
                        minHeight: '200px',
                        minWidth: '187px',
                        mobile: {
                            minHeight: '157px',
                            minWidth: '150px',
                        },
                    },
                    imageContainer: {
                        maxWidth: '427px',
                        padding: '18px',
                        mobile: {
                            maxWidth: '342px',
                        },
                    },
                    userInfoText: {
                        fontSize: '18px',
                        mobile: {
                            fontSize: '14px',
                        },
                    },
                },
                large: {
                    image: {
                        minHeight: '200px',
                        minWidth: '187px',
                        mobile: {
                            minHeight: '157px',
                            minWidth: '150px',
                        },
                    },
                    imageContainer: {
                        maxWidth: '427px',
                        padding: '18px',
                        mobile: {
                            maxWidth: '342px',
                        },
                    },
                    userInfoText: {
                        fontSize: '18px',
                        mobile: {
                            fontSize: '14px',
                        },
                    },
                },
            },
        },
        total: {
            basicTotal: {
                amount: {
                    color: '--colors-shades-550-color',
                    fontSize: '24px',
                },
                currency: {
                    color: '--colors-shades-550-color',
                    fontSize: '14px',
                    lineHeight: '22px',
                    alignSelf: 'flex-end',
                },
                savings: {
                    amountFontWeight: 600,
                    color: '--colors-semantic-positive-color',
                },
            },
        },
        subTotal: {
            basicSubTotal: {
                family: 'Jost',
                size: '14px',
                weight: 600,
                lineHeight: '22px',
                color: '--colors-shades-550-color',
            },
        },
        pricing: {
            priceLabel: {
                price: {
                    size: ComponentSize.Small,
                    originalPriceColor: '--colors-shades-300-color',
                    actualPriceColor: '--colors-semantic-urgent-color',
                },
            },
        },
        orderSummary: {
            headingTextAlign: 'center',
            backgroundColor: '--colors-shades-10-color',
            padding: '20px',
            borderRadius: '--radius-regular',
            maxWidth: '100%',
            onMobile: {
                maxWidth: '100%',
                padding: '15px',
            },
        },
        expressCheckout: {
            button: {
                borderRadius: '24px',
            },
        },
        copyrightText: {
            fontSize: '16px',
            fontWeight: 400,
            lineHeight: '24px',
            color: '--colors-pallete-secondary-color',
        },
        thankyouFooterText: {
            fontSize: '14px',
            fontWeight: '700',
            lineHeight: '20px',
        },
        textButton: {
            fontWeight: 500,
            lineHeight: 'normal',
        },
        deliveryDetails: {
            title: {
                fontSize: '1.25rem',
                lineHeight: '1.75rem',
                fontWeight: 600,
            },
            sectionTitle: {
                fontSize: '1.125rem',
                lineHeight: '1.25rem',
                fontWeight: 700,
            },
            note: {
                accentColor: '--colors-semantic-urgent-color',
                color: '--colors-text-color',
                backgroundColor: '--colors-pallete-primary-20-color',
            },
            sectionDetails: {
                fontSize: '1rem',
                lineHeight: '1.25rem',
                fontWeight: 400,
            },
        },
        text: {
            orderHeader: {
                color: '--colors-pallete-primary-color',
            },
            fitGuarantee: {
                fontWeight: 200,
            },
            offerBanner: {
                borderRadius: '1.25rem',
            },
        },
        orderBar: {
            backgroundColor: '#F7F4F2',
            fontColor: '--colors-shades-700-color',
        },
        banner: {
            outlineColor: '--colors-semantic-urgent-color',
            filledColor: '--colors-semantic-urgent-color',
            fontColor: '--colors-shades-white-color',
        },
        offerTitleText: {
            size: '18px',
            weight: 700,
            lineHeight: '1.7rem',
        },
        linePrice: {
            color: '--colors-semantic-urgent-color',
            badge: {
                color: '--colors-semantic-urgent-color',
                borderRadius: '8px',
            },
        },
        divider: {
            color: '--colors-pallete-secondary-soft-color',
        },
        checkout: {
            paymentInformation: {
                borderRadius: '24px',
            },
            creditCardSection: {
                borderRadius: '24px',
            },
        },
        upsell: {
            banner: {
                outlined: {
                    color: '--colors-semantic-positive-color',
                },
            },
            price: {
                colors: {
                    regular: '--colors-shades-400-color',
                    deal: '--colors-pallete-primary-color',
                    each: '--colors-shades-700-color',
                    badgeBG: '--colors-pallete-primary-color',
                    badgeColor: '--colors-shades-white-color',
                },
            },
            hurryTimeCard: {
                backgroundColor: '#FCD7B8',
            },
            guaranteedFit: {
                backgroundColor: '#FFF5E9',
            },
        },
        thankyou: {
            orderBanner: {
                text: {
                    left: '53%',
                },
            },
            emailSection: {
                backgroundColor: '--colors-pallete-champagne-color',
            },
            socialIcon: {
                color: '--colors-pallete-primary-color',
            },
            orderId: {
                color: '--colors-shades-700-color',
            },
        },
        hurryUp: {
            borderRadius: '1.5rem',
        },
        qtyPicker: {
            borderRadius: '1.125rem',
        },
    },
    fonts: {
        url: 'https://cdn.jsdelivr.net/gh/trafilea/storefront-static@main/fonts/truekind',
        config: [
            {
                family: 'CircularXX',
                src: 'CircularXX-Regular.otf',
                weight: 'normal',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-RegularItalic.otf',
                weight: 'normal',
                style: 'italic',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-Bold.otf',
                weight: 'bold',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-BoldItalic.otf',
                weight: 'bold',
                style: 'italic',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-Thin.otf',
                weight: 100,
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-ThinItalic.otf',
                weight: 100,
                style: 'italic',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-Light.otf',
                weight: 200,
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-LightItalic.otf',
                weight: 200,
                style: 'italic',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-Regular.otf',
                weight: 300,
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-RegularItalic.otf',
                weight: 300,
                style: 'italic',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-Book.otf',
                weight: 400,
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-BookItalic.otf',
                weight: 400,
                style: 'italic',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-Medium.otf',
                weight: 500,
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-MediumItalic.otf',
                weight: 500,
                style: 'italic',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-Bold.otf',
                weight: 700,
                stretch: 'condensed',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-BoldItalic.otf',
                weight: 700,
                stretch: 'condensed',
                style: 'italic',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-BlackItalic.otf',
                weight: 800,
                stretch: 'condensed',
                style: 'italic',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-Black.otf',
                weight: 800,
                stretch: 'condensed',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-ExtraBlack.otf',
                weight: 900,
                stretch: 'condensed',
            },
            {
                family: 'CircularXX',
                src: 'CircularXX-ExtraBlackItalic.otf',
                weight: 900,
                stretch: 'condensed',
                style: 'italic',
            },
        ],
    },
    assets: {
        cdn: 'https://cdn.jsdelivr.net/gh/trafilea/storefront-static@1.3.4/common',
        images: {
            favicon: 'https://cdn.shopify.com/s/files/1/0450/0901/0853/files/1_32x.png',
            logo: 'https://cdn.jsdelivr.net/gh/trafilea/storefront-static@main/images/truekind/tkd_logo_checkout.svg',
            logoSize: {
                width: '204',
                height: '35',
            },
            checkoutLogo: {
                url: 'https://cdn.jsdelivr.net/gh/trafilea/storefront-static@main/images/truekind/tkd_logo_checkout.svg',
                width: '204',
                height: '35',
            },
            upsellLogo: {
                url: 'https://cdn.jsdelivr.net/gh/trafilea/storefront-static@main/images/truekind/tkd_logo_checkout.svg',
                width: '210',
                height: '40',
            },
            tyLogo: {
                url: 'https://cdn.jsdelivr.net/gh/trafilea/storefront-static@main/images/truekind/tkd_logo_checkout.svg',
                width: '276',
                height: '50',
            },
        },
    },
};

module.exports = truekind;
